@@ -23,7 +23,7 @@
  *    Danielle Madeley <danielle.madeley@collabora.co.uk>
  */
 
-#include <mission-control-plugins/mission-control-plugins.h>
+#include "config.h"
 
 #include "mcp-account-manager-goa.h"
 
