@@ -27,6 +27,7 @@
 #include <tp-account-widgets/tpaw-contactinfo-utils.h>
 #include <tp-account-widgets/tpaw-time.h>
 #include <tp-account-widgets/tpaw-utils.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #ifdef HAVE_LIBCHAMPLAIN
 #include <champlain/champlain.h>
@@ -1294,12 +1295,11 @@ notify_presence_cb (gpointer folks_object,
       goto out;
     }
 
-  /* FIXME: Default messages should be moved into libfolks (bgo#627403) */
   message = folks_presence_details_get_presence_message (
       FOLKS_PRESENCE_DETAILS (folks_object));
   if (TPAW_STR_EMPTY (message))
     {
-      message = empathy_presence_get_default_message (presence);
+      message = folks_presence_details_get_default_message_from_type (presence);
     }
 
   if (message != NULL)
@@ -1308,7 +1308,8 @@ notify_presence_cb (gpointer folks_object,
   g_free (markup_text);
 
   gtk_image_set_from_icon_name (GTK_IMAGE (state_image),
-      empathy_icon_name_for_presence (presence),
+      empathy_icon_name_for_presence (
+        empathy_folks_presence_type_to_tp (presence)),
       GTK_ICON_SIZE_BUTTON);
 
 out:
