@@ -66,7 +66,7 @@ local_cmdline (GApplication *app,
   GError *error = NULL;
   GSimpleAction *action;
   gchar **argv;
-  gint argc;
+  gint argc = 0;
   gint i;
   gboolean retval = TRUE;
 
@@ -113,7 +113,7 @@ local_cmdline (GApplication *app,
         }
       else
         {
-          g_warning("Impossible to register empathy-debugger: %s", error->message);
+          g_warning ("Impossible to register empathy-debugger: %s", error->message);
           g_clear_error (&error);
           *exit_status = EXIT_FAILURE;
         }
