@@ -69,7 +69,6 @@ struct _TpawAccountWidgetPriv {
   GtkWidget *cancel_button;
   GtkWidget *entry_password;
   GtkWidget *spinbutton_port;
-  GtkWidget *radiobutton_reuse;
   GtkWidget *action_area;
 
   gboolean simple;
@@ -579,8 +578,8 @@ tpaw_account_widget_setup_widget (TpawAccountWidget *self,
           gtk_entry_set_visibility (GTK_ENTRY (widget), FALSE);
 
           /* Add 'clear' icon */
-          gtk_entry_set_icon_from_stock (GTK_ENTRY (widget),
-              GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_CLEAR);
+          gtk_entry_set_icon_from_icon_name (GTK_ENTRY (widget),
+              GTK_ENTRY_ICON_SECONDARY, "edit-clear-symbolic");
 
           gtk_entry_set_icon_sensitive (GTK_ENTRY (widget),
               GTK_ENTRY_ICON_SECONDARY, !TPAW_STR_EMPTY (str));
@@ -769,9 +768,11 @@ accounts_widget_generic_setup (TpawAccountWidget *self,
           gtk_widget_show (widget);
 
           widget = gtk_entry_new ();
+          g_object_set (widget, "hexpand", TRUE, NULL);
           if (g_strcmp0 (tp_connection_manager_param_get_name (param),
                 "account") == 0)
             {
+              g_object_set (widget, "width-request", 280, NULL);
               g_signal_connect (widget, "realize",
                   G_CALLBACK (gtk_widget_grab_focus),
                   NULL);
@@ -990,16 +991,6 @@ tpaw_account_widget_apply_and_log_in (TpawAccountWidget *self)
 {
   gboolean display_name_overridden;
 
-  if (self->priv->radiobutton_reuse != NULL)
-    {
-      gboolean reuse = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-            self->priv->radiobutton_reuse));
-
-      DEBUG ("Set register param: %d", !reuse);
-      tpaw_account_settings_set (self->priv->settings, "register",
-          g_variant_new_boolean (!reuse));
-    }
-
   g_object_get (self->priv->settings,
       "display-name-overridden", &display_name_overridden, NULL);
 
@@ -1311,7 +1302,6 @@ account_widget_build_jabber (TpawAccountWidget *self,
   GtkWidget *spinbutton_port;
   GtkWidget *checkbutton_ssl;
   GtkWidget *label_id, *label_password;
-  GtkWidget *label_id_create, *label_password_create;
   GtkWidget *label_example_fb;
   GtkWidget *label_example;
   GtkWidget *expander_advanced;
@@ -1330,20 +1320,9 @@ account_widget_build_jabber (TpawAccountWidget *self,
       self->ui_details->gui = tpaw_builder_get_resource (filename,
           "vbox_jabber_simple", &box,
           "label_id_simple", &label_id,
-          "label_id_create", &label_id_create,
           "label_password_simple", &label_password,
-          "label_password_create", &label_password_create,
           NULL);
 
-      if (tpaw_account_settings_get_boolean (self->priv->settings,
-            "register"))
-        {
-          gtk_widget_hide (label_id);
-          gtk_widget_hide (label_password);
-          gtk_widget_show (label_id_create);
-          gtk_widget_show (label_password_create);
-        }
-
       tpaw_account_widget_handle_params (self,
           "entry_id_simple", "account",
           "entry_password_simple", "password",
@@ -1745,126 +1724,34 @@ do_get_property (GObject *object,
 static void
 set_apply_button (TpawAccountWidget *self)
 {
+  const gchar *stock_image;
   GtkWidget *image;
 
-  /* We can't use the stock button as its accelerator ('A') clashes with the
-   * Add button. */
-  gtk_button_set_use_stock (GTK_BUTTON (self->priv->apply_button), FALSE);
-
-  gtk_button_set_label (GTK_BUTTON (self->priv->apply_button), _("A_pply"));
-  gtk_button_set_use_underline (GTK_BUTTON (self->priv->apply_button), TRUE);
-
-  image = gtk_image_new_from_stock (GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON);
-  gtk_button_set_image (GTK_BUTTON (self->priv->apply_button), image);
-}
-
-static void
-presence_changed_cb (TpAccountManager *manager,
-    TpConnectionPresenceType state,
-    const gchar *status,
-    const gchar *message,
-    TpawAccountWidget *self)
-{
-  if (self->priv->destroyed)
-    return;
-
-  if (self->priv->apply_button == NULL)
-    /* This button doesn't exist in 'simple' mode */
-    return;
-
-  if (state > TP_CONNECTION_PRESENCE_TYPE_OFFLINE &&
-      self->priv->creating_account)
+  if (self->priv->creating_account)
     {
-      /* We are online and creating a new account, display a Login button */
-      GtkWidget *image;
-
-      gtk_button_set_use_stock (GTK_BUTTON (self->priv->apply_button), FALSE);
-      gtk_button_set_label (GTK_BUTTON (self->priv->apply_button),
-          _("L_og in"));
-
-      image = gtk_image_new_from_stock (GTK_STOCK_CONNECT,
-          GTK_ICON_SIZE_BUTTON);
-      gtk_button_set_image (GTK_BUTTON (self->priv->apply_button), image);
+      gtk_button_set_label (GTK_BUTTON (self->priv->apply_button), _("A_dd"));
+      stock_image = GTK_STOCK_ADD;
     }
   else
     {
-      /* We are offline or modifying an existing account, display
-       * a Save button */
-      set_apply_button (self);
-    }
-}
+      /* We can't use the stock button as its accelerator ('A') clashes with the
+       * Add button. */
+      gtk_button_set_use_stock (GTK_BUTTON (self->priv->apply_button), FALSE);
+      gtk_button_set_label (GTK_BUTTON (self->priv->apply_button), _("A_pply"));
 
-static void
-account_manager_ready_cb (GObject *source_object,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  TpawAccountWidget *self = TPAW_ACCOUNT_WIDGET (user_data);
-  TpAccountManager *account_manager = TP_ACCOUNT_MANAGER (source_object);
-  GError *error = NULL;
-  TpConnectionPresenceType state;
-
-  if (!tp_proxy_prepare_finish (account_manager, result, &error))
-    {
-      DEBUG ("Failed to prepare account manager: %s", error->message);
-      g_error_free (error);
-      goto out;
+      stock_image = GTK_STOCK_APPLY;
     }
 
-  state = tp_account_manager_get_most_available_presence (account_manager, NULL,
-      NULL);
+  gtk_button_set_use_underline (GTK_BUTTON (self->priv->apply_button), TRUE);
 
-  /* simulate a presence change so the apply button will be changed
-   * if needed */
-  presence_changed_cb (account_manager, state, NULL, NULL, self);
-
-out:
-  g_object_unref (self);
+  image = gtk_image_new_from_stock (stock_image, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image (GTK_BUTTON (self->priv->apply_button), image);
 }
 
 #define WIDGET(cm, proto) \
   { #cm, #proto, TPAW_ACCOUNT_WIDGETS_RESOURCES_PREFIX "/tpaw-account-widget-"#proto".ui", \
     account_widget_build_##proto }
 
-static void
-add_register_buttons (TpawAccountWidget *self,
-    TpAccount *account)
-{
-  TpProtocol *protocol;
-  GtkWidget *radiobutton_register;
-
-  if (!self->priv->creating_account)
-    return;
-
-  protocol = tpaw_account_settings_get_tp_protocol (self->priv->settings);
-  if (protocol == NULL)
-    return;
-
-  if (!tp_protocol_can_register (protocol))
-    return;
-
-  if (account_widget_get_service (self) != NO_SERVICE)
-    return;
-
-  if (self->priv->simple)
-    return;
-
-  self->priv->radiobutton_reuse = gtk_radio_button_new_with_label (NULL,
-      _("This account already exists on the server"));
-  radiobutton_register = gtk_radio_button_new_with_label (
-      gtk_radio_button_get_group (
-        GTK_RADIO_BUTTON (self->priv->radiobutton_reuse)),
-      _("Create a new account on the server"));
-
-  gtk_box_pack_start (GTK_BOX (self), self->priv->radiobutton_reuse, FALSE,
-      FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (self), radiobutton_register, FALSE, FALSE, 0);
-  gtk_box_reorder_child (GTK_BOX (self), self->priv->radiobutton_reuse, 0);
-  gtk_box_reorder_child (GTK_BOX (self), radiobutton_register, 1);
-  gtk_widget_show (self->priv->radiobutton_reuse);
-  gtk_widget_show (radiobutton_register);
-}
-
 static void
 remember_password_toggled_cb (GtkToggleButton *button,
     TpawAccountWidget *self)
@@ -1910,7 +1797,6 @@ static void
 do_constructed (GObject *obj)
 {
   TpawAccountWidget *self = TPAW_ACCOUNT_WIDGET (obj);
-  TpAccount *account;
   const gchar *display_name, *default_display_name;
   guint i = 0;
   struct {
@@ -1933,8 +1819,6 @@ do_constructed (GObject *obj)
   const gchar *protocol, *cm_name;
   GtkWidget *box;
 
-  account = tpaw_account_settings_get_account (self->priv->settings);
-
   cm_name = tpaw_account_settings_get_cm (self->priv->settings);
   protocol = tpaw_account_settings_get_protocol (self->priv->settings);
 
@@ -2020,10 +1904,7 @@ do_constructed (GObject *obj)
 
   /* dup and init the account-manager */
   self->priv->account_manager = tp_account_manager_dup ();
-
-  g_object_ref (self);
-  tp_proxy_prepare_async (self->priv->account_manager, NULL,
-      account_manager_ready_cb, self);
+  tp_proxy_prepare_async (self->priv->account_manager, NULL, NULL, NULL);
 
   if (!self->priv->external_action_area)
     {
@@ -2049,12 +1930,6 @@ do_constructed (GObject *obj)
   self->priv->apply_button = gtk_button_new ();
   set_apply_button (self);
 
-  /* We'll change this button to a "Log in" one if we are creating a new
-   * account and are connected. */
-  tp_g_signal_connect_object (self->priv->account_manager,
-      "most-available-presence-changed",
-      G_CALLBACK (presence_changed_cb), obj, 0);
-
   gtk_box_pack_end (GTK_BOX (self->priv->action_area),
       self->priv->cancel_button, TRUE, TRUE, 3);
   gtk_box_pack_end (GTK_BOX (self->priv->action_area),
@@ -2081,8 +1956,6 @@ do_constructed (GObject *obj)
   else
     account_widget_set_control_buttons_sensitivity (self, FALSE);
 
-  add_register_buttons (self, account);
-
   g_clear_object (&self->ui_details->gui);
 
   display_name = tpaw_account_settings_get_display_name (
