@@ -18,12 +18,8 @@
  * 02111-1307, USA.
  */
 
-#include <glib.h>
-
-#include <gcr/gcr.h>
-
-#include <p11-kit/pkcs11.h>
 #include <gck/pkcs11x.h>
+#include <gcr/gcr.h>
 
 #ifndef MOCK_MODULE_H
 #define MOCK_MODULE_H
